@@ -60,10 +60,10 @@ public:
     void set_sample_rate(uint32_t sr);
     float get_output_level();
     float get_comp_level();
-    bool get_graph(int subindex, float *data, int points, cairo_iface *context, int *mode) const;
-    bool get_dot(int subindex, float &x, float &y, int &size, cairo_iface *context) const;
-    bool get_gridline(int subindex, float &pos, bool &vertical, std::string &legend, cairo_iface *context) const;
-    bool get_layers(int index, int generation, unsigned int &layers) const;
+    bool _get_graph(int subindex, float *data, int points, cairo_iface *context, int *mode) const;
+    bool _get_dot(int subindex, float &x, float &y, int &size, cairo_iface *context) const;
+    bool _get_gridline(int subindex, float &pos, bool &vertical, std::string &legend, cairo_iface *context) const;
+    bool _get_layers(int index, int generation, unsigned int &layers) const;
 };
 
 /**********************************************************************
@@ -78,7 +78,7 @@ private:
     float attack, release, threshold, ratio, knee, makeup, detection, stereo_link, bypass, mute, meter_out, meter_comp;
     float old_threshold, old_ratio, old_knee, old_makeup, old_bypass, old_mute, old_detection, old_stereo_link;
     mutable bool redraw_graph;
-    float old_y1,old_yl,old_detected;
+    float old_y1, old_yl, old_mre, old_mae;
     uint32_t srate;
     bool is_active;
     inline float output_level(float inputt) const;
@@ -94,10 +94,10 @@ public:
     void set_sample_rate(uint32_t sr);
     float get_output_level();
     float get_comp_level();
-    bool get_graph(int subindex, float *data, int points, cairo_iface *context, int *mode) const;
-    bool get_dot(int subindex, float &x, float &y, int &size, cairo_iface *context) const;
-    bool get_gridline(int subindex, float &pos, bool &vertical, std::string &legend, cairo_iface *context) const;
-    bool get_layers(int index, int generation, unsigned int &layers) const;
+    bool _get_graph(int subindex, float *data, int points, cairo_iface *context, int *mode) const;
+    bool _get_dot(int subindex, float &x, float &y, int &size, cairo_iface *context) const;
+    bool _get_gridline(int subindex, float &pos, bool &vertical, std::string &legend, cairo_iface *context) const;
+    bool _get_layers(int index, int generation, unsigned int &layers) const;
 };
 
 /**********************************************************************
@@ -126,10 +126,10 @@ public:
     void set_sample_rate(uint32_t sr);
     float get_output_level();
     float get_expander_level();
-    bool get_graph(int subindex, float *data, int points, cairo_iface *context, int *mode) const;
-    bool get_dot(int subindex, float &x, float &y, int &size, cairo_iface *context) const;
-    bool get_gridline(int subindex, float &pos, bool &vertical, std::string &legend, cairo_iface *context) const;
-    bool get_layers(int index, int generation, unsigned int &layers) const;
+    bool _get_graph(int subindex, float *data, int points, cairo_iface *context, int *mode) const;
+    bool _get_dot(int subindex, float &x, float &y, int &size, cairo_iface *context) const;
+    bool _get_gridline(int subindex, float &pos, bool &vertical, std::string &legend, cairo_iface *context) const;
+    bool _get_layers(int index, int generation, unsigned int &layers) const;
 };
 
 /**********************************************************************
