@@ -417,7 +417,7 @@ char *jack_host::configure(const char *key, const char *value)
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-static const char *short_options = "c:i:l:o:m:M:s:S:ehvL";
+static const char *short_options = "c:i:l:o:m:M:s:S:ehvLnt";
 
 static struct option long_options[] = {
     {"help", 0, 0, 'h'},
@@ -432,14 +432,17 @@ static struct option long_options[] = {
     {"connect-midi", 1, 0, 'M'},
     {"session-id", 1, 0, 'S'},
     {"list", 0, 0, 'L'},
+    {"no-gui", 0, 0, 'n'},
+    {"no-tray", 0, 0, 't'},
     {0,0,0,0},
 };
 
 void print_help(char *argv[])
 {
     printf("JACK host for Calf effects\n"
-        "Syntax: %s [--client <name>] [--input <name>] [--output <name>] [--midi <name>] [--load|state <session>]\n"
-        "       [--connect-midi <name|capture-index>] [--help] [--version] [--list] [!] pluginname[:<preset>] [!] ...\n", 
+        "Syntax: %s [--client, -c <name>] [--input, -i <name>] [--output, -o <name>] [--midi, -m <name>] [--load|state, -l|s <session>]\n"
+        "       [--connect-midi, -M <name|capture-index>] [--help, -h] [--version, -v] [--list, -L] [--no-tray, -t]\n"
+        "       [!] pluginname[:<preset>] [!] ...\n", 
         argv[0]);
 }
 
@@ -459,7 +462,6 @@ int main(int argc, char *argv[])
         sess.calfjackhost_cmd = path;
         free(path);
     }
-    sess.session_env->init_gui(argc, argv);
     
     // Scan the options for the first time to find switches like --help, -h or -?
     // This avoids starting communication with LASH when displaying help text.
@@ -511,6 +513,13 @@ int main(int argc, char *argv[])
             case 'S':
                 sess.jack_session_id = optarg;
                 break;
+            case 'n':
+                sess.has_gui = false;
+                sess.has_trayicon = false;
+                break;
+            case 't':
+                sess.has_trayicon = false;
+                break;
             case 'l':
             case 's':
             {
@@ -569,12 +578,23 @@ int main(int argc, char *argv[])
         fprintf(stderr, "Error while loading presets: %s\n", e.what());
         exit(1);
     }
+
+        
     try {
+        if(sess.has_gui){
+            sess.session_env->init_gui(argc, argv);
+        }
         sess.open();
         sess.connect();
         sess.client.activate();
         sess.set_signal_handlers();
-        sess.session_env->start_gui_loop();
+        if (sess.has_gui) {
+            sess.session_env->start_gui_loop();
+        } else {
+            while (sess.quit_on_next_idle_call == 0){
+                sleep(1);
+            }   
+        }
         sess.close();
     }
     catch(std::exception &e)
