@@ -23,6 +23,7 @@
 #include <calf/giface.h>
 #include <calf/audio_fx.h>
 #include <calf/modules_limit.h>
+#include <calf/utils.h>
 
 using namespace dsp;
 using namespace calf_plugins;
@@ -59,9 +60,11 @@ void limiter_audio_module::deactivate()
 }
 void limiter_audio_module::set_srates()
 {
-    resampler[0].set_params(srate, *params[param_oversampling], 2);
-    resampler[1].set_params(srate, *params[param_oversampling], 2);
-    limiter.set_sample_rate(srate * *params[param_oversampling]);
+    if (params[param_oversampling]) {
+        resampler[0].set_params(srate, *params[param_oversampling], 2);
+        resampler[1].set_params(srate, *params[param_oversampling], 2);
+        limiter.set_sample_rate(srate * *params[param_oversampling]);
+    }
 }
 void limiter_audio_module::params_changed()
 {
@@ -70,7 +73,7 @@ void limiter_audio_module::params_changed()
         attack_old = *params[param_attack];
         limiter.reset();
     }
-    if(*params[param_limit] != limit_old or *params[param_asc] != asc_old) {
+    if(*params[param_limit] != limit_old || *params[param_asc] != asc_old) {
         asc_old = *params[param_asc];
         limit_old = *params[param_limit];
         limiter.reset_asc();
@@ -128,7 +131,7 @@ uint32_t limiter_audio_module::process(uint32_t offset, uint32_t numsamples, uin
             float tmpR;
             
             // process gain reduction
-            float fickdich[0];
+            STACKALLOC(float, fickdich, limiter.overall_buffer_size);
             for (int i = 0; i < *params[param_oversampling]; i ++) {
                 tmpL = samplesL[i];
                 tmpR = samplesR[i];
@@ -149,8 +152,10 @@ uint32_t limiter_audio_module::process(uint32_t offset, uint32_t numsamples, uin
             outR = std::min(std::max(outR, -*params[param_limit]), *params[param_limit]);
 
             // autolevel
-            outL /= *params[param_limit];
-            outR /= *params[param_limit];
+            if (*params[param_auto_level]) {
+                outL /= *params[param_limit];
+                outR /= *params[param_limit];
+            }
 
             // out level
             outL *= *params[param_level_out];
@@ -271,7 +276,7 @@ void multibandlimiter_audio_module::params_changed()
     }
     
     // rebuild multiband buffer
-    if( *params[param_attack] != attack_old or *params[param_oversampling] != oversampling_old) {
+    if( *params[param_attack] != attack_old || *params[param_oversampling] != oversampling_old) {
         int bs           = (int)(srate * (*params[param_attack] / 1000.f) * channels * over);
         buffer_size      = bs - bs % channels; // buffer size attack rate
         attack_old       = *params[param_attack];
@@ -283,7 +288,7 @@ void multibandlimiter_audio_module::params_changed()
         }
         broadband.reset();
     }
-    if(*params[param_limit] != limit_old or *params[param_asc] != asc_old or *params[param_weight0] != weight_old[0] or *params[param_weight1] != weight_old[1] or *params[param_weight2] != weight_old[2] or *params[param_weight3] != weight_old[3] ) {
+    if(*params[param_limit] != limit_old || *params[param_asc] != asc_old || *params[param_weight0] != weight_old[0] || *params[param_weight1] != weight_old[1] || *params[param_weight2] != weight_old[2] || *params[param_weight3] != weight_old[3] ) {
         asc_old    = *params[param_asc];
         limit_old  = *params[param_limit];
         for (int j = 0; j < strips; j ++) {
@@ -456,7 +461,7 @@ uint32_t multibandlimiter_audio_module::process(uint32_t offset, uint32_t numsam
                 }
                 
                 // process broadband limiter
-                float fickdich[0];
+                STACKALLOC(float, fickdich, broadband.overall_buffer_size);
                 tmpL = resL[o];
                 tmpR = resR[o];
                 broadband.process(tmpL, tmpR, fickdich);
@@ -482,8 +487,10 @@ uint32_t multibandlimiter_audio_module::process(uint32_t offset, uint32_t numsam
             }
             
             // autolevel
-            outL /= *params[param_limit];
-            outR /= *params[param_limit];
+            if (*params[param_auto_level]) {
+                outL /= *params[param_limit];
+                outR /= *params[param_limit];
+            }
 
             // out level
             outL *= *params[param_level_out];
@@ -667,7 +674,7 @@ void sidechainlimiter_audio_module::params_changed()
     }
     
     // rebuild multiband buffer
-    if( *params[param_attack] != attack_old or *params[param_oversampling] != oversampling_old) {
+    if( *params[param_attack] != attack_old || *params[param_oversampling] != oversampling_old) {
         int bs           = (int)(srate * (*params[param_attack] / 1000.f) * channels * over);
         buffer_size      = bs - bs % channels; // buffer size attack rate
         attack_old       = *params[param_attack];
@@ -679,7 +686,7 @@ void sidechainlimiter_audio_module::params_changed()
         }
         broadband.reset();
     }
-    if(*params[param_limit] != limit_old or *params[param_asc] != asc_old or *params[param_weight0] != weight_old[0] or *params[param_weight1] != weight_old[1] or *params[param_weight2] != weight_old[2] or *params[param_weight3] != weight_old[3] ) {
+    if(*params[param_limit] != limit_old || *params[param_asc] != asc_old || *params[param_weight0] != weight_old[0] || *params[param_weight1] != weight_old[1] || *params[param_weight2] != weight_old[2] || *params[param_weight3] != weight_old[3] ) {
         asc_old    = *params[param_asc];
         limit_old  = *params[param_limit];
         for (int j = 0; j < strips; j ++) {
@@ -839,7 +846,7 @@ uint32_t sidechainlimiter_audio_module::process(uint32_t offset, uint32_t numsam
                 }
                 
                 // process broadband limiter
-                float fickdich[0];
+                STACKALLOC(float, fickdich, broadband.overall_buffer_size);
                 tmpL = resL[o];
                 tmpR = resR[o];
                 broadband.process(tmpL, tmpR, fickdich);
@@ -865,8 +872,10 @@ uint32_t sidechainlimiter_audio_module::process(uint32_t offset, uint32_t numsam
             }
             
             // autolevel
-            outL /= *params[param_limit];
-            outR /= *params[param_limit];
+            if (*params[param_auto_level]) {
+                outL /= *params[param_limit];
+                outR /= *params[param_limit];
+            }
 
             // out level
             outL *= *params[param_level_out];
