@@ -28,6 +28,7 @@
 #include <calf/modules_dist.h>
 #include <calf/modules_filter.h>
 #include <calf/modules_mod.h>
+#include <calf/modules_pitch.h>
 #include <calf/modules_synths.h>
 #include <calf/organ.h>
 
@@ -65,6 +66,13 @@ audio_module_iface *create_calf_plugin_by_name(const char *effect_name)
     return NULL;
 }
 
+plugin_metadata_iface *create_calf_metadata_by_name(const char *effect_name)
+{
+    #define PER_MODULE_ITEM(name, isSynth, jackname) if (!strcasecmp(effect_name, jackname)) return new name##_metadata;
+    #include <calf/modulelist.h>
+    return NULL;
+}
+
 }
 
 #endif
